@@ -25,6 +25,8 @@ _moduleLogger = logging.getLogger(__name__)
 if not pygame.font:
 	_moduleLogger.info('Warning, fonts disabled')
 if not pygame.mixer:
+	config.gameSound = False
+	config.gameMusic = False
 	_moduleLogger.info('Warning, sound disabled')
 
 
@@ -36,12 +38,19 @@ DATA_FOLDER = os.path.join(os.path.dirname(__file__), "data")
 class nomMain(object):
 
 	def __init__(self , width=800, height=480):
-		pygame.mixer.pre_init(44100, -16, 1, 256)
+		try:
+			pygame.mixer.pre_init(44100, -16, 1, 256)
+		except pygame.error:
+			config.gameMusic = False
+			config.gameSound = False
+			_moduleLogger.exception("Disabling sound support")
 		pygame.init()
 		pygame.mouse.set_visible(False)
 		try:
 			pygame.mixer.init()
 		except pygame.error:
+			config.gameMusic = False
+			config.gameSound = False
 			_moduleLogger.exception("Disabling sound support")
 		self._clock = pygame.time.Clock()
 		DATA_FOLDER = os.path.join(os.path.dirname(__file__), "data")
